/**********************************************************************\
*                                                                      *
*  display.c -- graphics display functions, bitmaps, scrolling, etc.   *
*                                                                      *
\**********************************************************************/

#include "defs.h"
#include "tntmaps.h"

/**********************************************************************\
*                                                                      *
*  do_bitmaps -- display some bitmaps on the screen                    *
*                                                                      *
*  the drawmap bitmaps are bigger than the drwimage bitmaps but you    *
*  can have any transparent and visual colors you want                 *
*                                                                      *
\**********************************************************************/

do_bitmaps()
{
   /* width, height, position and colors of TNT plunger bitmap */

   static int tnt_width[]   = { 6,  3,  4,  4};
   static int tnt_height[]  = {28, 25, 27, 17};
   static int tnt_color[]   = { 0,  7,  8, 15};
   static int tnt_xoffset[] = { 0, 24, 16, 16};
   static int tnt_yoffset[] = { 0, -2, -1, -2};
   static char *tnt_bitmap[4] = {tnt0,tnt7,tnt8,tnt15};

   /* width, height, position and colors of "kablooy" explosion */

   static int kablooy_width[]   = {13,  6};
   static int kablooy_height[]  = {53,  8};
   static int kablooy_color[]   = { 4, 15};
   static int kablooy_xoffset[] = { 0, 29};
   static int kablooy_yoffset[] = { 0,-24};
   static char *kablooy_bitmap[2] = {kablooy4,kablooy15};

   /* strings for info window */

   static char *string[] = {
   "Bitmaps",
   "Bitmaps can be clipped, flipped, mode-independent",
   "and mode-specific.",
   };

   register int i;
   int x,y;
   int ymin,ymax;

   /* clear lower part of screen */

   fg_mousevis(OFF);
   fg_restore(0,xlimit,menu_bottom,ylimit);

   /* display the info window */

   info_window(120,520,60,string,3);

   /* calculate where the TNT bitmap is going to go */

   ymin = 60;
   ymax = ymin + 4 * (ptsize+1);

   x = 520;
   y = ymax;

   /* put the TNT bitmap next to the info window */

   fg_mousevis(OFF);
   for (i = 0; i < 4; i++)
   {
      fg_move(x+tnt_xoffset[i],y+tnt_yoffset[i]);
      fg_setcolor(tnt_color[i]);
      fg_drawmap(tnt_bitmap[i],tnt_width[i],tnt_height[i]);
   }

   /* save info window to hidden page, to be replaced after the explosion */

   x = 440;
   y = ymax + 20;
   fg_save(400,520,ymin,y);

   /* take a rectangular bite out of the info window on the hidden page */

   fg_transfer(464,568,144,180,464,y-10,hidden,hidden);

   /* pause 1 second */

   fg_mousevis(ON);
   fg_waitfor(18);

   /* move the plunger down */

   fg_mousevis(OFF);
   fg_transfer(544,567,ymax-30,ymax-25,0,5,visual,hidden);
   fg_transfer(0,23,0,5,544,ymax-23,hidden,visual);
   fg_mousevis(ON);
   fg_waitfor(6);

   fg_mousevis(OFF);
   fg_transfer(0,23,0,5,544,ymax-21,hidden,visual);
   fg_mousevis(ON);
   fg_waitfor(6);
   fg_mousevis(OFF);

   /* display the explosion */

   for (i = 0; i < 2; i++)
   {
      fg_move(x+kablooy_xoffset[i],y+kablooy_yoffset[i]);
      fg_setcolor(kablooy_color[i]);
      fg_drawmap(kablooy_bitmap[i],kablooy_width[i],kablooy_height[i]);
   }

   /* blink the "kablooy" text 4 times */

   for (i = 0; i < 4; i++)
   {
      fg_waitfor(3);
      fg_move(x+kablooy_xoffset[1],y+kablooy_yoffset[1]);
      fg_setcolor(4);
      fg_drawmap(kablooy_bitmap[1],kablooy_width[1],kablooy_height[1]);
      fg_waitfor(3);
      fg_move(x+kablooy_xoffset[1],y+kablooy_yoffset[1]);
      fg_setcolor(15);
      fg_drawmap(kablooy_bitmap[1],kablooy_width[1],kablooy_height[1]);
   }

   /* wait a bit, then restore the info window with the corner missing */

   fg_waitfor(3);
   fg_restore(440,568,y-68,y);

   /* draw the torn edges of the info window using the tear bitmap */

   fg_setcolor(0);
   fg_move(461,ymax);
   fg_drawmap(tear,8,29);

   /* restore all the stuff on the hidden page */

   draw_screen(3);

   /* wait for a keystroke, restore the visual page, and return */

   fg_mousevis(ON);
   wait_for_keystroke();

   fg_mousevis(OFF);
   fg_restore(0,xlimit,menu_bottom,ylimit);

   fg_mousevis(ON);
   redraw = TRUE;

   return(OK);
}

/**********************************************************************\
*                                                                      *
*  do_borland -- display the Borland logo (we obtained a license from  *
*                Borland to do this!)                                  *
*                                                                      *
\**********************************************************************/

int do_borland()
{
   if (!exists("borland.pcx"))
      abort_program("File missing: Borland.pcx.\n");

   fg_mousevis(0);
   fg_setpage(hidden);
   fg_showpcx("borland.pcx",0);

   fg_tcmask(0x7fee);
   fg_tcxfer(32,295,7,191,188,300,hidden,visual);

   /* copy the visual page to the hidden page */

   fg_setpage(visual);
   fg_save(0,639,0,349);
   fg_setpage(hidden);
   fg_setcolor(15);
   fg_rect(188,339,40,300);
   fg_rect(340,495,122,300);
   fg_setcolor(11);
   fg_drect(188,339,40,300,matrix2);
   fg_drect(340,495,122,300,matrix2);

   /* wait for a keystroke */

   fg_mousevis(ON);
   wait_for_keystroke();

   /* copy menu screen from hidden to visual */

   fg_mousevis(OFF);
   fg_fadein(0);
   fg_mousevis(ON);

   /* restore the screen and return to the menu */

   redraw = TRUE;
   return(OK);
}

/**********************************************************************\
*                                                                      *
*  do_dub -- wavering Fastgraph logo courtesy of Dub Media             *
*            Dub Media does renderings and sprite animation for        *
*            game programmers. Call Mike or Alfred at (617)647-1101    *
*                                                                      *
\**********************************************************************/

int do_dub()
{
   int i,j,x,y;
   int x1,y2;
   int stall_time;

   if (!exists("Dub.pcx"))
      abort_program("File missing: Dub.pcx.\n");

   stall_time = clockspeed/4;
   fg_mousevis(0);
   fg_setpage(hidden);
   fg_showpcx("dub.pcx",0);

   /* clear the visual screen below the menu */

   fg_setpage(visual);
   fg_setcolor(0);
   fg_rect(4,635,39,346);

   /* redraw the menu with no options highlighted */

   horizontal_menu(main_menu,-ITEMS,-3);
   fg_mousevis(0);

   /* put the first mousie on the screen */

   fg_transfer(32,137,235,297,520,336,hidden,visual);

   /* draw the other mice on the screen in sequence */

   x1 = 56;
   y2 = 100;
   fg_setcolor(0);
   for (j = 0; j < 2; j++)
   {
      for (i = 1; i < 4; i++)
      {
         for (x = 0; x < 640; x+=160)
         {
            for (y = 56; y <= 224; y+= 56)
            {
               fg_rect(x1-8,x1-1,y2-56,y2);
               fg_transfer(x,x+159,y-56,y,x1,y2,hidden,visual);
               fg_stall(stall_time);
               y2++;
               x1+= 8;
            }
         }
      }

      for (i = 1; i < 4; i++)
      {
         for (x = 0; x < 640; x+=160)
         {
            for (y = 56; y <= 224; y+= 56)
            {
               fg_rect(x1-8,x1-1,y2-56,y2);
               fg_transfer(x,x+159,y-56,y,x1,y2,hidden,visual);
               fg_stall(stall_time);
               y2++;
               x1-= 8;
            }
         }
      }
   }

   for (i = 1; i < 3; i++)
   {
      for (x = 0; x < 640; x+=160)
      {
         for (y = 56; y <= 224; y+= 56)
         {
            fg_rect(x1-8,x1-1,y2-56,y2);
            fg_transfer(x,x+159,y-56,y,x1,y2,hidden,visual);
            fg_stall(stall_time);
            y2++;
            x1+= 8;
         }
      }
   }

   /* redraw the menu on the hidden page */

   fg_setpage(hidden);
   draw_screen(3);

   /* wait for a keystroke */

   fg_mousevis(ON);
   wait_for_keystroke();

   fg_mousevis(OFF);

   /* restore the screen and return to the menu */

   fg_restore(0,xlimit,0,ylimit);
   redraw = TRUE;
   fg_fadein(0);
   fg_palettes(default_colors);
   fg_mousevis(ON);

   return(OK);
}

/**********************************************************************\
*                                                                      *
*  do_scroll -- do a circular scroll of part of the screen             *
*                                                                      *
\**********************************************************************/

do_scroll()
{
   register int i;
   int y1,y2;

   y1 = 4;
   y2 = ylimit - y1;

   fg_mousevis(OFF);

   /* save the area under the scroll */

   fg_transfer(280,439,y1,y2,0,y2,hidden,hidden);

   /* do a nice circular scroll */

   for (i = y1; i <= y2; i+=2)
      fg_scroll(280,439,y1,y2,-2,0);

   /* fix the area under the scroll */

   fg_transfer(0,159,y1,y2,280,y2,hidden,hidden);
   fg_save(0,159,y1,y2);

   fg_mousevis(ON);
   return(OK);
}

/**********************************************************************\
*                                                                      *
* do_transfer -- demo the transfer function                            *
*                                                                      *
\**********************************************************************/

do_transfer()
{
   register int i;
   int x,y;
   int ymin,ymax;

   static char *string[] = {
   "Transfer",
   "Use Fastgraph's image transfer routines",
   "to copy rectangular areas, either on the",
   "same video page or different video pages."
    };

   /* clear work area of visual page and display the info window */

   fg_mousevis(OFF);
   fg_restore(0,xlimit,menu_bottom,ylimit);
   info_window(24,419,60,string,4);

   /* save the info window to the hidden page */

   ymin = 60;
   ymax = ymin + 5 * (ptsize+1) + 2;
   fg_save(24,419,ymin,ymax);

   /* transfer a 6 copies of the info window from hidden page to visual */

   x = 56;
   y = ymax+ptsize+1;
   for (i = 0; i < 6; i++)
   {
      fg_transfer(24,419,ymin,ymax,x,y,hidden,visual);
      x += 32;
      y += ptsize;
      fg_waitfor(2);
   }

   /* wait for a keystroke */

   fg_mousevis(ON);
   wait_for_keystroke();

   fg_mousevis(OFF);

   /* clear the area where the info window was on the hidden page */

   y = 5 * (ptsize+1) + 2;

   fg_transfer(24,419,ymax+1,ymax+y+1,24,ymax,hidden,hidden);

   /* restore the screen and return */

   fg_restore(0,xlimit,menu_bottom,ylimit);
   redraw = TRUE;

   fg_mousevis(ON);
   return(OK);
}

